<template>
  <div :class="className" :style="{ height: height, width: width }" />
</template>

<script>
import echarts from 'echarts';
require('echarts/theme/macarons'); // echarts theme
// import resize from './mixins/resize';

export default {
  //   mixins: [resize],
  props: {
    className: {
      type: String,
      default: 'chart'
    },
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '350px'
    },
    autoResize: {
      type: Boolean,
      default: true
    },
    chartData: {
      type: Object,
      required: true
    }
  },
  data() {
    return {
      chart: null
    };
  },
  watch: {
    chartData: {
      deep: true,
      handler(val) {
        this.setOptions(val);
      }
    }
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart();
    });
  },
  beforeDestroy() {
    if (!this.chart) {
      return;
    }
    this.chart.dispose();
    this.chart = null;
  },
  methods: {
    initChart() {
      this.chart = echarts.init(this.$el, 'macarons');
      this.setOptions(this.chartData);
    },
    getRandomColor() {
      return '#' + ('00000' + ((Math.random() * 0x1000000) << 0).toString(16)).substr(-6);
    },
    setOptions(chartData) {
      if (!chartData || !chartData.data) {
        return;
      }
      const series = chartData.data.map(item => {
        const randomColor = this.getRandomColor();
        return {
          name: item.name,
          itemStyle: {
            normal: {
              color: randomColor,
              lineStyle: {
                color: randomColor,
                width: 2
              }
            }
          },
          smooth: true,
          type: 'line',
          data: item.data,
          animationDuration: 2800,
          animationEasing: 'cubicInOut'
        };
      });

      const legendData = chartData.data.map(item => item.name);

      this.chart.setOption({
        xAxis: {
          data: chartData.dimension,
          boundaryGap: false,
          axisTick: {
            show: false
          }
        },
        grid: {
          left: 10,
          right: 10,
          bottom: 20,
          top: 30,
          containLabel: true
        },
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'cross'
          },
          formatter:function (params) {
            console.log(params)
            var res=params[0].name
            for(var i=0;i<params.length;i++){
              res +="<br>"+params[i].marker+params[i].seriesName+":"+params[i].data
            }
            return res
          }
        },
        yAxis: {
          axisTick: {
            show: false
          }
        },
        legend: {
          data: legendData
        },
        series: series
      });
    }
  }
};
</script>
